:::{include} ../../README.md
:::

:::{toctree}
:hidden:
install
command_line
faq
esef
user_guides/user_guides
plugins/plugins
python_api/python_api
contributor_guides/contributor_guides
license
apidocs/index
genindex
:::
